@@ -1,6 +1,8 @@
+import uuid
 from sqlalchemy import Column
 from sqlalchemy.dialects.postgresql import UUID
 from sqlalchemy.ext.declarative import declared_attr
+from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import relationship, synonym
 
 from sqlalchemy_api_handler.bases.errors import ActivityError
@@ -11,7 +13,7 @@ from sqlalchemy_api_handler.utils.humanize import humanize, humanize_ids_in
 
 
 class ActivityMixin(object):
-    entityIdentifier = Column(UUID(as_uuid=True))
+    _entityIdentifier = None
 
     @declared_attr
     def dateCreated(cls):
@@ -23,19 +25,43 @@ class ActivityMixin(object):
 
     @property
     def datum(self):
-        if not self.data:
+        if self.data is None:
             return None
         model = self.model
         return synonyms_in(humanize_ids_in(self.data, self.model), model)
 
+    @property
+    def entityIdentifier(self):
+        if self._entityIdentifier:
+            return self._entityIdentifier
+        activity_identifier = self.data.get('activityIdentifier',
+                                            self.changed_data.get('activityIdentifier'))
+        if activity_identifier:
+            self._entityIdentifier = uuid.UUID(activity_identifier)
+            return self._entityIdentifier
+
+    @entityIdentifier.setter
+    def entityIdentifier(self, value):
+        self._entityIdentifier = value
+
     @property
     def model(self):
         return self.__class__.model_from_table_name(self.table_name)
 
+    @model.setter
+    def model(self, value):
+        self.table_name = value.__tablename__
+        return self.model
+
     @property
     def modelName(self):
         return self.model.__name__
 
+    @modelName.setter
+    def modelName(self, value):
+        model = self.__class__.model_from_name(value)
+        self.table_name = model.__tablename__
+
     @property
     def entity(self):
         model = self.model
@@ -43,48 +69,38 @@ class ActivityMixin(object):
 
     @property
     def oldDatum(self):
-        if not self.old_data:
+        if self.old_data is None:
             return None
         model = self.model
         return synonyms_in(humanize_ids_in(self.old_data, model), model)
 
     @property
     def patch(self):
-        if not self.changed_data:
+        if self.changed_data is None:
             return None
         model = self.model
         return synonyms_in(humanize_ids_in(self.changed_data, model), model)
 
-    def modify(self,
-               datum,
-               skipped_keys=[],
-               with_add=False):
-        dehumanized_datum = {**datum}
+    @patch.setter
+    def patch(self, value):
+        model = self.model
+        self.changed_data = dehumanize_ids_in(value, model)
 
-        if 'modelName' in datum:
+
+    def modify(self, datum, **kwargs):
+        if 'modelName' in datum and 'tableName' in datum:
             model = self.__class__.model_from_name(datum['modelName'])
-            if 'tableName' in datum:
-                if datum['tableName'] != model.__tablename__:
-                    errors = ActivityError()
-                    errors.add_error('modelName', '{} different from {}'.format(model.__tablename__,
-                                                                                datum['tableName']))
-                    raise errors
-            self.table_name = model.__tablename__
+            if datum['tableName'] != model.__tablename__:
+                errors = ActivityError()
+                errors.add_error('modelName', '{} different from {}'.format(model.__tablename__,
+                                                                            datum['tableName']))
+                raise errors
 
-        table_name = datum.get('tableName', self.tableName)
-        model = self.__class__.model_from_table_name(table_name)
-        for (humanized_key, dehumanized_key) in [('oldDatum', 'old_data'), ('patch', 'changed_data')]:
-            if humanized_key in dehumanized_datum:
-                dehumanized_datum[dehumanized_key] = dehumanize_ids_in(dehumanized_datum[humanized_key],
-                                                                       model)
-                del dehumanized_datum[humanized_key]
-
-        super().modify(dehumanized_datum,
-                       skipped_keys=skipped_keys,
-                       with_add=with_add)
+        super().modify(datum, **kwargs)
 
     __as_dict_includes__ = [
         'dateCreated',
+        'entityIdentifier',
         'modelName',
         'patch',
         'verb',
@@ -93,6 +109,7 @@ class ActivityMixin(object):
         '-native_transaction_id',
         '-old_data',
         '-table_name',
+        '-relid',
         '-schema_name',
         '-transaction_id'
     ]
